=================================
astrodendro.dendrogram.Dendrogram
=================================

.. currentmodule:: astrodendro.dendrogram

.. autoclass:: Dendrogram

   .. rubric:: Attributes

   .. autosummary::

      ~Dendrogram.trunk
      ~Dendrogram.leaves
      ~Dendrogram.all_structures

   .. rubric:: Analysis

   .. autosummary::

      ~Dendrogram.compute
      ~Dendrogram.structure_at

   .. rubric:: Input/Output

   .. autosummary::

      ~Dendrogram.save_to
      ~Dendrogram.load_from

   .. rubric:: Visualization

   .. autosummary::

      ~Dendrogram.plotter
      ~Dendrogram.viewer

   .. rubric:: Methods (detail)

   .. automethod:: Dendrogram.compute
   .. automethod:: Dendrogram.structure_at

   .. automethod:: Dendrogram.save_to
   .. automethod:: Dendrogram.load_from

   .. automethod:: Dendrogram.plotter
   .. automethod:: Dendrogram.viewer
